@@ -25,6 +25,7 @@
 
 #include <KXmlGuiWindow>
 #include <KTabWidget>
+#include <KAction>
 
 namespace Sonnet {
     class DictionaryComboBox;
@@ -107,6 +108,7 @@ private Q_SLOTS:
     void onZoomIn();
     void onZoomOut();
     void onZoomFactorChanged(qreal zoom);
+    void updateSendMessageShortcuts();
 
 protected Q_SLOTS:
     void showSettingsDialog();
@@ -168,6 +170,8 @@ private:
     /** Returns whether there's at least one tab with unread message */
     bool hasUnreadMessages() const;
 
+    KAction *m_sendMessage;
+
     KTabWidget *m_tabWidget;
 
     Sonnet::DictionaryComboBox *m_spellDictCombo;
