@@ -20,6 +20,7 @@
 #include "telepathy-chat-ui.h"
 #include "chat-tab.h"
 #include "chat-window.h"
+#include "text-chat-config.h"
 
 #include <KDebug>
 #include <KConfigGroup>
@@ -39,23 +40,11 @@ inline Tp::ChannelClassSpecList channelClassList()
 }
 
 
-TelepathyChatUi::TelepathyChatUi()
-    : KTp::TelepathyHandlerApplication(true, -1, -1), AbstractClientHandler(channelClassList())
+TelepathyChatUi::TelepathyChatUi(const Tp::AccountManagerPtr &accountManager)
+    : KTp::TelepathyHandlerApplication(true, -1, -1), AbstractClientHandler(channelClassList()),
+      m_accountManager(accountManager)
 {
     kDebug();
-
-    KSharedConfigPtr config = KSharedConfig::openConfig(QLatin1String("ktelepathyrc"));
-    KConfigGroup tabConfig = config->group("Behavior");
-
-    // load the settings for new tab "open mode"
-    QString mode = tabConfig.readEntry("tabOpenMode", "FirstWindow");
-    if (mode == QLatin1String("NewWindow")) {
-        m_openMode = NewWindow;
-    } else if (mode == QLatin1String("FirstWindow")) {
-        m_openMode = FirstWindow;
-    } else if (mode == QLatin1String("LastWindow")) {
-        m_openMode = LastWindow;
-    }
 }
 
 void TelepathyChatUi::removeWindow(ChatWindow *window)
@@ -154,14 +143,14 @@ void TelepathyChatUi::handleChannels(const Tp::MethodInvocationContextPtr<> & co
     }
 
     //if there is currently no tab containing the incoming channel.
+
     if (!tabFound) {
         ChatWindow* window = 0;
-        switch (m_openMode) {
-            case FirstWindow:
+        switch (TextChatConfig::instance()->openMode()) {
+            case TextChatConfig::FirstWindow:
                 window = m_chatWindows.count()?m_chatWindows[0]:createWindow();
                 break;
-            case LastWindow:
-            case NewWindow:
+            case TextChatConfig::NewWindow:
                 window = createWindow();
                 break;
         }
@@ -185,3 +174,8 @@ bool TelepathyChatUi::bypassApproval() const
     return false;
 }
 
+Tp::AccountManagerPtr TelepathyChatUi::accountManager() const
+{
+    return m_accountManager;
+}
+
