@@ -470,7 +470,7 @@ void ChatWidget::onHistoryFetched(const QList<AdiumThemeContentInfo> &messages)
 
     //process any messages we've 'missed' whilst initialising.
     Q_FOREACH(const Tp::ReceivedMessage &message, d->channel->messageQueue()) {
-        handleIncomingMessage(message);
+        handleIncomingMessage(message, true);
     }
 }
 
@@ -489,13 +489,18 @@ void ChatWidget::acknowledgeMessages()
     }
 }
 
+void ChatWidget::updateSendMessageShortcuts(const KShortcut &shortcuts)
+{
+    d->ui.sendMessageBox->setSendMessageShortcuts(shortcuts);
+}
+
 bool ChatWidget::isOnTop() const
 {
     kDebug() << ( isActiveWindow() && isVisible() );
     return ( isActiveWindow() && isVisible() );
 }
 
-void ChatWidget::handleIncomingMessage(const Tp::ReceivedMessage &message)
+void ChatWidget::handleIncomingMessage(const Tp::ReceivedMessage &message, bool alreadyNotified)
 {
     kDebug() << title() << message.text();
 
@@ -618,8 +623,10 @@ void ChatWidget::handleIncomingMessage(const Tp::ReceivedMessage &message)
 
             // FIXME: eventually find a way to make MessageProcessor allow per
             //        instance filters.
-            d->notifyFilter->filterMessage(processedMessage,
-                                           KTp::MessageContext(d->account, d->channel));
+            if (!alreadyNotified) {
+                d->notifyFilter->filterMessage(processedMessage,
+                                               KTp::MessageContext(d->account, d->channel));
+            }
 
             messageInfo.setMessage(processedMessage.finalizedMessage());
             messageInfo.setScript(processedMessage.finalizedScript());
@@ -708,7 +715,7 @@ void ChatWidget::sendMessage()
 
     if (!message.isEmpty()) {
         message = KTp::MessageProcessor::instance()->processOutgoingMessage(
-                    message, d->account, d->channel).mainMessagePart();
+                    message, d->account, d->channel).text();
 
         if (d->channel->supportsMessageType(Tp::ChannelTextMessageTypeAction) && message.startsWith(QLatin1String("/me "))) {
             //remove "/me " from the start of the message
@@ -788,8 +795,7 @@ void ChatWidget::onContactPresenceChange(const Tp::ContactPtr & contact, const K
     }
 
     if (!message.isNull()) {
-        if ((d->ui.chatArea->showPresenceMode() == AdiumThemeView::Always) ||
-            ((d->ui.chatArea->showPresenceMode() == AdiumThemeView::NeverInGroupChats) && d->isGroupChat)) {
+        if (d->ui.chatArea->showPresenceChanges()) {
             AdiumThemeStatusInfo statusMessage;
             statusMessage.setMessage(message);
             statusMessage.setService(d->channel->connection()->protocolName());
